/*
 * InstallUtils.java
 *
 * Created on 09 October 2006, 12:50
 *
 * www.starjar.com
 *             +
 *     +       *       +
 *       *     *     *
 *         *   *   *
 *           * * *
 *   - * * * * * * * * * -
 *           * * *
 *         *   *   *
 *       *     *     *
 *     +       *       +
 *             +
 *
 *     SSSS  TTTTTTT    A     RRRRR   JJJJJJJ    A     RRRRR
 *    S    S    T      A A    R    R     J      A A    R    R
 *    S         T     A   A   R    R     J     A   A   R    R
 *      SSS     T    A     A  RRRRR      J    A     A  RRRRR
 *         S    T   AAAAAAAAA R   R      J   AAAAAAAAA R   R
 *    S    S    T   A       A R    R  J  J   A       A R    R  ..
 *     SSS      T   A       A R    R   JJJ   A       A R    R  ..
 *
 * Copyright (c) 2007 Peter Henderson. All Rights Reserved.
 */

package breakglassfishstandaloneclient;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.Iterator;
import java.util.Map;

/**
 * A collection of handy functions for web start applications.
 *
 * @author peter
 */
public class InstallUtils {
    
    /**
     * Install a file from the application classpath onto the users computer.
     * The file is only installed if it does not already exist.
     * Before copying the file, the destination directory tree is created if
     * needed.
     *
     * @param srcFilename Source file name in class path
     * @param destinationFilename Destination file name to install to
     * @param replacements A map of tokens to replace in the file. Can be null
     */
    public static void installFile( String srcFilename, String destinationFilename, Map<String,String> replacements ) {
        File destinationFile = new File( destinationFilename );
        
        try {
            if( !destinationFile.exists() ) {
                System.out.println( "Installing '" + srcFilename + "' to '" + destinationFilename + "'" );
                
                // get the file from classpath
                InputStream is  = Thread.currentThread().getContextClassLoader().getResourceAsStream( srcFilename );
                StringBuilder sb = new StringBuilder(300);
                int c;
                while( (c=is.read())!=-1 ) {
                    char ch = (char)c;
                    sb.append(ch);
                }
                
                String str = sb.toString();
                
                // Replace tokens in the file.
                if( replacements!=null ) {
                    Iterator<String> keyit = replacements.keySet().iterator();
                    while( keyit.hasNext() ) {
                        String key = keyit.next();
                        String value = replacements.get(key);
                        str = str.replaceAll( key, value );
                    }
                }
                
                // save
                // make the dir tree
                File destDir = new File( destinationFile.getParent() );
                destDir.mkdirs();
                
                // write file
                FileOutputStream fos = new FileOutputStream( destinationFile );
                fos.write( str.getBytes() );
                fos.close();
            }
        } catch(Exception e) {
            System.out.println("Failure installing file" + srcFilename + " . " + e.toString() );
            e.printStackTrace();
        }
    }

}
